qustop.PPT
==========

.. currentmodule:: qustop

.. autoclass:: PPT

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PPT.__init__
      ~PPT.dual_problem
      ~PPT.primal_problem
      ~PPT.solve
   
   

   
   
   